@@ -1218,6 +1218,6 @@ def test_stacktrace_big_recursion(sentry_init, capture_events):
 
     # On my machine, it takes about 100-200ms to capture the exception,
     # so this limit should be generous enough.
-    assert (
-        capture_end_time - capture_start_time < 10**9 * 2
-    ), "stacktrace capture took too long, check that frame limit is set correctly"
+    assert capture_end_time - capture_start_time < 10**9 * 2, (
+        "stacktrace capture took too long, check that frame limit is set correctly"
+    )
