@@ -137,13 +137,11 @@ def test_transport_works(
         (compression_level is None)
         or (
             # setting compression level to 0 means don't compress
-            compression_level
-            > 0
+            compression_level > 0
         )
     ) and (
         # if we couldn't resolve to a known algo, we don't compress
-        compression_algo
-        != "<invalid>"
+        compression_algo != "<invalid>"
     )
 
     assert capturing_server.captured[0].compressed == should_compress
@@ -593,17 +591,17 @@ def test_complex_limits_without_data_category(
 
 
 @pytest.mark.parametrize("response_code", [200, 429])
-def test_metric_bucket_limits(capturing_server, response_code, make_client):
+def test_log_item_limits(capturing_server, response_code, make_client):
     client = make_client()
     capturing_server.respond_with(
         code=response_code,
         headers={
-            "X-Sentry-Rate-Limits": "4711:metric_bucket:organization:quota_exceeded:custom"
+            "X-Sentry-Rate-Limits": "4711:log_item:organization:quota_exceeded:custom"
         },
     )
 
     envelope = Envelope()
-    envelope.add_item(Item(payload=b"{}", type="statsd"))
+    envelope.add_item(Item(payload=b"{}", type="log"))
     client.transport.capture_envelope(envelope)
     client.flush()
 
@@ -611,7 +609,7 @@ def test_metric_bucket_limits(capturing_server, response_code, make_client):
     assert capturing_server.captured[0].path == "/api/132/envelope/"
     capturing_server.clear_captured()
 
-    assert set(client.transport._disabled_until) == set(["metric_bucket"])
+    assert set(client.transport._disabled_until) == {"log_item"}
 
     client.transport.capture_envelope(envelope)
     client.capture_event({"type": "transaction"})
@@ -625,81 +623,7 @@ def test_metric_bucket_limits(capturing_server, response_code, make_client):
     assert envelope.items[0].type == "client_report"
     report = parse_json(envelope.items[0].get_bytes())
     assert report["discarded_events"] == [
-        {"category": "metric_bucket", "reason": "ratelimit_backoff", "quantity": 1},
-    ]
-
-
-@pytest.mark.parametrize("response_code", [200, 429])
-def test_metric_bucket_limits_with_namespace(
-    capturing_server, response_code, make_client
-):
-    client = make_client()
-    capturing_server.respond_with(
-        code=response_code,
-        headers={
-            "X-Sentry-Rate-Limits": "4711:metric_bucket:organization:quota_exceeded:foo"
-        },
-    )
-
-    envelope = Envelope()
-    envelope.add_item(Item(payload=b"{}", type="statsd"))
-    client.transport.capture_envelope(envelope)
-    client.flush()
-
-    assert len(capturing_server.captured) == 1
-    assert capturing_server.captured[0].path == "/api/132/envelope/"
-    capturing_server.clear_captured()
-
-    assert set(client.transport._disabled_until) == set([])
-
-    client.transport.capture_envelope(envelope)
-    client.capture_event({"type": "transaction"})
-    client.flush()
-
-    assert len(capturing_server.captured) == 2
-
-    envelope = capturing_server.captured[0].envelope
-    assert envelope.items[0].type == "statsd"
-    envelope = capturing_server.captured[1].envelope
-    assert envelope.items[0].type == "transaction"
-
-
-@pytest.mark.parametrize("response_code", [200, 429])
-def test_metric_bucket_limits_with_all_namespaces(
-    capturing_server, response_code, make_client
-):
-    client = make_client()
-    capturing_server.respond_with(
-        code=response_code,
-        headers={
-            "X-Sentry-Rate-Limits": "4711:metric_bucket:organization:quota_exceeded"
-        },
-    )
-
-    envelope = Envelope()
-    envelope.add_item(Item(payload=b"{}", type="statsd"))
-    client.transport.capture_envelope(envelope)
-    client.flush()
-
-    assert len(capturing_server.captured) == 1
-    assert capturing_server.captured[0].path == "/api/132/envelope/"
-    capturing_server.clear_captured()
-
-    assert set(client.transport._disabled_until) == set(["metric_bucket"])
-
-    client.transport.capture_envelope(envelope)
-    client.capture_event({"type": "transaction"})
-    client.flush()
-
-    assert len(capturing_server.captured) == 2
-
-    envelope = capturing_server.captured[0].envelope
-    assert envelope.items[0].type == "transaction"
-    envelope = capturing_server.captured[1].envelope
-    assert envelope.items[0].type == "client_report"
-    report = parse_json(envelope.items[0].get_bytes())
-    assert report["discarded_events"] == [
-        {"category": "metric_bucket", "reason": "ratelimit_backoff", "quantity": 1},
+        {"category": "log_item", "reason": "ratelimit_backoff", "quantity": 1},
     ]
 
 
